#
# spec file for package netsniff-ng
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           netsniff-ng
Version:        0.6.8
Release:        3.2
Summary:        Network Sniffer for Packet Inspection
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
URL:            http://netsniff-ng.org/
Source:         http://pub.netsniff-ng.org/netsniff-ng/netsniff-ng-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  libcli-devel
BuildRequires:  libnet-devel
BuildRequires:  libnetfilter_conntrack-devel
BuildRequires:  libnl3-devel
BuildRequires:  libpcap-devel
BuildRequires:  libsodium-devel
BuildRequires:  libtool
BuildRequires:  liburcu-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(ncursesw)
Patch0:         netsniff-ng-ncursesw.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
netsniff-ng is a network sniffer for packet inspection. It is similar
to tcpdump, and likewise uses a memory mapped area for accessing
packets. It can be used for protocol analysis and reverse
engineering, network debugging, measurement of performance
throughput, or network statistics creation of incoming packets on
central network nodes like routers or firewalls.

The netsniff-ng toolkit consists of the following utilities:

* netsniff-ng, a zero-copy analyzer, pcap capturing and replaying tool
* trafgen, a multithreaded low-level zero-copy network packet generator
* mausezahn, high-level packet generator for HW/SW appliances with Cisco-CLI
* bpfc, a Berkeley Packet Filter compiler, Linux BPF JIT disassembler
* ifpps, a top-like kernel networking statistics tool
* flowtop, a top-like netfilter connection tracking tool
* curvetun, a curve25519-based IP tunnel
* astraceroute, an autonomous system (AS) trace route utility

%prep
%autosetup -p1

%build
export NACL_LIB=sodium
export NACL_INC_DIR=/usr/include/sodium
./configure --disable-geoip
make %{?_smp_mflags} ETCDIR=%{_sysconfdir} Q= STRIP=: CFLAGS="%{optflags}"

%install
# disable parrallel execution with -j1 because it cause an error with make 4.4
make -j1 install PREFIX=%{_prefix} ETCDIR=%{_sysconfdir} DESTDIR=%{buildroot}

%files
%license COPYING
%doc AUTHORS README REPORTING-BUGS
%dir %{_sysconfdir}/netsniff-ng
%config(noreplace) %{_sysconfdir}/netsniff-ng/*
%{_sbindir}/*
%{_mandir}/man8/*

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Wed Dec 21 2022 Michael Pujos <pujos.michael@gmail.com>
- fixed build failure caused by make install failing due to make 4.4
  behavior change in target ordering when parrallelism is enabled.
  For this, -j1 is passed to make install to disable parrallelism
* Mon Jan 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.8
  * Bugfix release
  * remove "CFLAGS+=-fcommon"
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon
* Mon May  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.7
  * trafgen: reset errno before calling sscanf in str2mac
  * ifpps: fix iface stat parsing if interface name contains
    uppercase characters
  * mausezahn: fix display of missing argument error
  * mausezahn: support -R to set packet priority
  * netsniff-ng: handle various malformed packets in protocol
    dissectors
* Thu Nov  7 2019 Martin Hauke <mardnh@gmx.de>
- Do not longer build with support for GeoIP
  GeoIP has been discontinued by Maxmind. Please see
  https://support.maxmind.com/geolite-legacy-discontinuation-notice/
  for details. Without the database GeoIP is useless.
* Thu May  9 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.6.6
  * implement rotating capture files in netsniff-ng
  * fixed '--in -' to work again with STDIN in trafgen
  * fixed -t 0 option to use sendto in trafgen
  * checksum calculation for ICMP and TCP in astraceroute
  * fix for reading mirrors from file in astraceroute
  * use GZIP_ENV instead of GZIP in build system
  * fixed manpage warnings
  * added error handling for mismatched address families in mausezahn.
- Update to version 0.6.5
  * add DCCP support to netsniff-ng
  * fix segfault in mausezahn
  * add date format strings to --out in netsniff-ng
  * restore handling of raw hex string passed in on command line in
    mausezahn
  * support ICMPv6 checksums in trafgen
  * improve random mac address generation in mausezahn
  * man page updates and reformatting
* Thu Nov 15 2018 Cristian Rodríguez <crrodriguez@opensuse.org>
-  netsniff-ng-ncursesw.patch replaces netsniff-ng-fix-ncurses.diff
  choose ncurses6w and not ncurses5 for build.
* Fri Jan  5 2018 mardnh@gmx.de
- Update to version 0.6.4
  * DNS header generation in trafgen
  * Support for dumping proto headers in trafgen
  * Fixes for dinc()/ddec() to properly respect min/max range and
    avoid counter corruption
  * Fixes for NULL pointer dereferences and resource leaks in trafgen
  * Build fixes for various compiler versions, libc implementations
    and distributions
- Rebase patch:
  * netsniff-ng-fix-ncurses.diff
* Thu Jun  1 2017 mardnh@gmx.de
- Use ncurses5-devel instead of ncurses-devel for Tumbleweed
* Fri May 26 2017 jengelh@inai.de
- Trim filler wording.
* Tue Apr 11 2017 mardnh@gmx.de
- update to 0.6.3
  - Allow to specify packet offsets in trafgen packet header functions.
    By Vadim Kochan.
  - Allow trafgen to send packets from pcap file. By Vadim Kochan.
  - Support trafgen interface without IP address in packet header
    functions. By Ken Wu.
  - Various other improvements and cleanups in the packet header
    functions of trafgen. By Vadim Kochan.
  - Tab based user interface for flowtop. Introduced a tab for flow
    statistics per PID. By Vadim Kochan.
  - Fixed buffer overflow in device_addr2str() causing Linux cooked header
    dissector to crash. Reported by @jamieparfet, fixed by Tobias Klauser.
  - Fixed build due to missing GENL_ID_GENERATE if compiling against
    kernel headers >= 4.10 (see issue #171).
    Reported by Jaroslav Škarvada (@yarda), fixed by Tobias Klauser.
* Mon Nov  7 2016 mardnh@gmx.de
- update to 0.6.2
  - Many improvements to the trafgen protocol generation functions,
    e.g. the ability to increment/randomize protocol fields at runtime
    using dinc()/rnd(), new functions to generate IPv6, ICMPv4/v6, PFC,
    and IEEE 802.3X PAUSE headers. From Vadim Kochan and Tobias Klauser.
  - flowtop UI improvements. From Vadim Kochan.
  - Packet counting fixes, e.g. to not account for duplicate packets
    received over the loopüback interface. From Paolo Abeni.
  - Allow IPv6 ranges to be specified for source and dest addresses
    in mausezahn. From Tommy Beadle.
  - Build system improvements, allowing to specify more options to the
    configure script. See './configure --help' for details.
    From Vadim Kochan and Tobias Klauser.
  - Various compilation fixes, e.g. for warnings or build failure
    certain systems. From Yousong Zhou and arch3y.
  - Various documentation improvements and fixes. From Vadim Kochan,
    Hisao Tanabe, and Tobias Klauser.
  - add patch netsniff-ng-fix-ncurses.diff
    fix some ncurses related issues during compile time
* Tue Mar 22 2016 mardnh@gmx.de
- update to 0.6.1
  - Newly added trafgen configuration language which allows to specify the
    packets in a more convenient format. See trafgen(8) for more details on
    the supported protocols and keywords.
  - Additional runtime commands for flowtop which allow to toggle/filter
    display of flows.
  - Command line options to pass macro definitions to trafgen and bpfc.
  - Made the build of all netsniff-ng tools reproducible (stable link order).
  - Fix download of GeoIP databases so the files don't get corrupted.
* Sat Nov  7 2015 mardnh@gmx.de
- update to 0.6.0
- removed patches (fixed upstream)
  - netsniff-ng-pkgconfig.diff
  - netsniff-ng-fix-manpage-perms.diff
* Wed Nov  4 2015 mardnh@gmx.de
- update to 0.5.9
- fix source-url
- removed old patches (upstream no longer use CMake)
  - netsniff-ng-optflags.patch
  - netsniff-ng-cmake_pod2man_without_stderr.patch
  - netsniff-pkgconfig.diff
- add patches
  - netsniff-ng-pkgconfig.diff (handle libnetfilter_conntrack)
  - netsniff-ng-fix-manpage-perms.diff (fix manpage permissions during install)
- now requires libnl-3 - removed all handling for different libnl versions
- build against libsodium instead of nacl
- ran speccleaner
* Thu Jun 20 2013 joop.boonen@opensuse.org
- corrected BuildRequires for libnl-devel
* Sun Jun 16 2013 jengelh@inai.de
- Properly search for libraries using pkgconfig
* Wed Jun 12 2013 joop.boonen@opensuse.org
- update to 0.5.7
* Thu Mar 29 2012 pascal.bleser@opensuse.org
- update to 0.5.6: see changelog
* Sat Sep 24 2011 andreas.stieger@gmx.de
- remove dependency in licenses, not in Factory anymore
* Mon Oct 11 2010 pascal.bleser@opensuse.org
- update to 0.5.5:
  * the PCAP file format is supported, which enables netsniff-ng to dump, read, and replay traces to or from harddisk
  * lots of new packet printing options were added, targeted for debugging and reverse engineering
  * automatic NIC IRQ affinity adaption is done if netsniff-ng is bound to a specific CPU
  * the possibility to manually set up ring size was added
  * POSIX compatible extended regular expression based filtering of packet content was implemented
* Thu Feb 18 2010 pascal.bleser@opensuse.org
- update to 0.5.4.2:
  * fixes an issue where, under specific conditions, netsniff-ng's
    rx_ring stops receiving packets
  * basic BPF checks have been added
* Sat Jan  2 2010 pascal.bleser@opensuse.org
- update to 0.5.4.1: patches merged upstream
* Fri Jan  1 2010 pascal.bleser@opensuse.org
- fix segfault in buffer overflow patch
* Thu Dec 31 2009 pascal.bleser@opensuse.org
- new package (0.5.4)
